import json

LINE_CHARACTERS = {
    "single": "─",
    "double": "═",
    "simple_dash": "-",
    "squigle": "~",
    "bold": "▬"
}
BOX_CHARACTERS = {
    "rounded": (("╭", "─", "╮"), ("╰", "─", "╯"), "│"),
    "sharp": (("┌", "─", "┐"), ("└", "─", "┘"), "│"),
    "tech": (("/", "─", "\\"), ("\\", "─", "/"), "│"),
    "simple": (("+", "-", "+"), ("+", "-", "+"), "|"),
    "double_box": (("╔", "═", "╗"), ("╚", "═", "╝"), "║"),
    "squigle": (("╭", "~", "╮"), ("╰", "~", "╯"), "│"),
    "bold": (("▄", "▀", "▄"), ("▀", "▄", "▀"), "█"),
}


class Decor():

    
    def init_box_style(StyleName: str, BoxChars: tuple):
        BOX_CHARACTERS[StyleName] = BoxChars

    def init_line_style(StyleName: str, LineChar: tuple):
        LINE_CHARACTERS[StyleName] = LineChar

    def drawLine(style, length):
        char = LINE_CHARACTERS[style]
        return char*length

        
    def boxstr(style, string):
        boxed_str = ""
        lines = string.splitlines()
        box_elements = BOX_CHARACTERS[style]
        width = max([len(i) for i in lines])
        boxed_str += f"{box_elements[0][0] + box_elements[0][1] * ((width // len(box_elements[0][1])) + 2) + box_elements[0][2]}\n"
        for i, line in enumerate(lines):
            boxed_str += f"{box_elements[2] + ' ' + lines[i] + ' ' + ' '  * (width-len(lines[i])) + box_elements[2]}\n"

        boxed_str += f"{box_elements[1][0] + box_elements[1][1] * (width // len(box_elements[1][1]) + 2) + box_elements[1][2]}"
        return boxed_str
    
    def prettyprint(seq, indent = 2):
        return json.dumps(seq, indent = indent)




# -----------------------------------Tests---------------------------------------------------- #


# Decor.drawLine("single", 40)
# Decor.drawLine("double", 40)
# Decor.drawLine("simple_dash", 40)
# Decor.drawLine("squigle", 40)
# Decor.drawLine("bold", 40)

#box("rounded", 10, 10)
#box("sharp", 10, 10)
#box("simple", 10, 10)
#box("double_box", 10, 10)
#box("tech", 10, 10)

# Decor.boxstr("rounded", """Hi this is great
# if this works"""
# )
# Decor.boxstr("sharp", """Hi this is great
# if this works"""
# )
# Decor.boxstr("simple", """Hi this is great
# if this works"""
# )
# Decor.boxstr("double_box", """Hi this is great
# if this works"""
# )
# Decor.boxstr("tech", """Hi this is great
# if this works"""
# )
# Decor.boxstr("squigle", """Hi this is great
# if this works"""
# )
# Decor.boxstr("bold", """Hi this is great
# if this works"""
# )



import platform

from .Decor import Decor
from .Win7_Colorizer import Win7_Colorizer
from .ANSI_Colorizer import ANSI_Colorizer
from .MenuDriver import MenuDriver
from .safe_exec import safe_exec


# TextColorizer = Win7_Colorizer
TextColorizer = Win7_Colorizer if "Windows" in platform.platform() and int(platform.release()) < 10 else ANSI_Colorizer


def colorizeText(string, FgColor : str = None, BgColor : str = None, JustTextBG: bool = False):

    only_text = JustTextBG

    TextColorizer(string = string, FgColor = FgColor, BgColor = BgColor).Colorize(JustTextBG = only_text)

def Input(prompt = "", FgColor : str = None, BgColor: str = None):
    value = TextColorizer(FgColor = FgColor, BgColor = BgColor).Input(prompt=prompt)
    return value

def Print(*text, sep: str = " ", end: str = "\n"):
    TextColorizer.Print(*text, sep = sep, end = end)

def init_boxStyle(StyleName: str, BoxChars: tuple):
    if StyleName != None and BoxChars != None:
        Decor.init_box_style(StyleName, BoxChars)
    else:
        pass


def init_lineStyle(StyleName: str, LineChar: tuple):
    if StyleName != None and LineChar != None:
        Decor.init_line_style(StyleName, LineChar)
    else:
        pass    


import curses

class ColorSet():
    WIN7_COLOR_SET = {
        "FOREGROUND": {
            "black": 0x0000,
            "blue": 0x0001,
            "green": 0x0002,
            "cyan": 0x0003,
            "red": 0x0004,
            "magenta": 0x0005,
            "yellow": 0x0006,
            "white": 0x0007,
            
            '''intensity = 0x0008   foreground color is intensified.'''

            "bright_black": 0x0000 | 0x0008,
            "bright_blue": 0x0001 | 0x0008,
            "bright_green": 0x0002 | 0x0008,
            "bright_cyan": 0x0003 | 0x0008,
            "bright_red": 0x0004 | 0x0008,
            "bright_magenta": 0x0005 | 0x0008,
            "bright_yellow": 0x0006,
            "bright_white": 0x0007 | 0x0008,
        },

        "BACKGROUND": {
            "black": 0x0000,
            "blue": 0x0010,
            "green": 0x0020,
            "cyan": 0x0030,
            "red": 0x0040,
            "magenta": 0x0050,
            "yellow": 0x0060,
            "white": 0x0070,

            '''intensity = 0x0080  background color is intensified.'''

            "bright_black": 0x0000 | 0x0080,
            "bright_blue": 0x0010 | 0x0080,
            "bright_green": 0x0020 | 0x0080,
            "bright_cyan": 0x0030 | 0x0080,
            "bright_red": 0x0040 | 0x0080,
            "bright_magenta": 0x0050 | 0x0080,
            "bright_yellow": 0x0060 | 0x0080,
            "bright_white": 0x0070 | 0x0080,
        }

    }

    ANSI_COLOR_SET = {
        "FOREGROUND": {
            "black": "30",
            "red": "31",
            "green": "32",
            "yellow": "33",
            "blue": "34",
            "magenta": "35",
            "cyan": "36",
            "white": "37",
            
            "bright_black": "90",
            "bright_red": "91",
            "bright_green": "92",
            "bright_yellow": "93",
            "bright_blue": "94",
            "bright_magenta": "95",
            "bright_cyan": "96",
            "bright_white": "97",
        },

        "BACKGROUND": {
            "black": "40",
            "red": "41",
            "green": "42",
            "yellow": "43",
            "blue": "44",
            "magenta": "45",
            "cyan": "46",
            "white": "47",

            "bright_black": "100",
            "bright_red": "101",
            "bright_green": "102",
            "bright_yellow": "103",
            "bright_blue": "104",
            "bright_magenta": "105",
            "bright_cyan": "106",
            "bright_white": "107",
        }


    }
    MENU_COLOR_SET = {
        
        "black": curses.COLOR_BLACK,
        "red": curses.COLOR_RED,
        "green": curses.COLOR_GREEN,
        "yellow": curses.COLOR_YELLOW,
        "blue": curses.COLOR_BLUE,
        "magenta": curses.COLOR_MAGENTA,
        "cyan": curses.COLOR_CYAN,
        "white": curses.COLOR_WHITE,

        "bright_black": curses.COLOR_BLACK | 0x0008,
        "bright_red": curses.COLOR_RED | 0x0008,
        "bright_green": curses.COLOR_GREEN | 0x0008,
        "bright_yellow": curses.COLOR_YELLOW | 0x0008,
        "bright_blue": curses.COLOR_BLUE | 0x0008,
        "bright_magenta": curses.COLOR_MAGENTA | 0x0008,
        "bright_cyan": curses.COLOR_CYAN | 0x0008,
        "bright_white": curses.COLOR_WHITE | 0x0008,


    }



# -------------------------------------Under development-------------------------------------------------

from .Decor import Decor
from .Win7_Colorizer import Win7_Colorizer
from .ANSI_Colorizer import ANSI_Colorizer


import sys
import platform
import os

TextColorizer = Win7_Colorizer if "Windows" in platform.platform() and int(platform.release()) < 10 else ANSI_Colorizer

def safe_exec():
    args = sys.argv
    filePath = args[-1]
    if "safe_exec" in args:
        if os.path.exists(filePath):
            with open(filePath) as f:
                contents = f.read()
                try:
                    exec(contents, globals())
                except Exception as e:
                    TextColorizer.DefaultBg = "bright_red"
                    TextColorizer.DefaultFg = "black"
                    TextColorizer().SetDefaultTheme()
                    TextColorizer.Print(f"Error: {e}")
                    TextColorizer.Print(f"Error type: {type(e).__name__}")

                    tb = e.__traceback__
                    while tb.tb_next:
                        tb = tb.tb_next
                        # TextColorizer.Print(f"Error raised at module: {tb.tb_frame.f_globals.get('__name__')}")

                    TextColorizer.Print(f"Error at line(in your file): {tb.tb_lineno}")
    elif ("safe_exec" in args and args[-1] == "--help") or ("safe_exec" in args and args[-1] == "-h"):
        TextColorizer.DefaultBg = "Black"
        TextColorizer.DefaultFg = "bright_cyan"
        TextColorizer().SetDefaultTheme()

        TextColorizer.Print(Decor.boxstr(string = """usage: prettyfy safe_exec <file-path>

Executes file vritually to find errors""",style = "simple"))
    elif ("prettyfy" in args and args[-1] == "--help") or("prettyfy" in args and args[-1] == "-h"):
        TextColorizer.DefaultBg = "Black"
        TextColorizer.DefaultFg = "bright_cyan"
        TextColorizer().SetDefaultTheme()
        TextColorizer.Print(Decor.boxstr(srting = 
"""usage: 
    
    prettyfy <command>

    Commands:

    safe_exec <file-path> : Executes file vritually to find errors"""
        ,style = "simple"))

    
    else:
        pass


from .ColorSet import ColorSet
from .Decor import Decor

import os
import sys


class ANSI_Colorizer:
    DefaultFg : str = "white"
    DefaultBg : str = "black"

    

    def Print(*text, sep: str = " ", end: str = "\n"):

        width = os.get_terminal_size().columns 
        text = (" ",) if text == () else text
        print_contents = " "

        if len(text) == 1:
            if type(text[0]).__name__ == "list" or type(text[0]).__name__ == "set" or type(text[0]).__name__ == "tuple" or type(text[0]).__name__ == "dict":
                print_contents = Decor.prettyprint(text[0])
            else:
                string_list = map(str, text)
                print_contents = sep.join(string_list)
        else:        
            string_list = map(str, text)
            print_contents = sep.join(string_list)

        lines = print_contents.splitlines()
        length = [(len(line), line) for line in lines]
        for line in length:
            
            print(line[1] + " " * (width - line[0]), sep = sep, end = end)


    def __init__(self, string = "", FgColor : str = None, BgColor : str = None) -> None:
        if sys.platform == 'win32': os.system("")

        self.COLORS = ColorSet.ANSI_COLOR_SET

        FgColor = self.DefaultFg if FgColor == None else FgColor
        BgColor = self.DefaultBg if BgColor == None else BgColor


        self.default_fg = self.COLORS["FOREGROUND"][self.DefaultFg]
        self.default_bg = self.COLORS["BACKGROUND"][self.DefaultBg]

        self.FgColor = self.COLORS["FOREGROUND"][FgColor]
        self.BgColor = self.COLORS["BACKGROUND"][BgColor]
        self.string = string

        self.ColorEscape = f"\x1b[{self.FgColor};{self.BgColor}m"
        self.DefaultColorEscape = f"\x1b[{self.default_fg};{self.default_bg}m"
        self.ResetEscape = "\x1b[37;40m"

    def eval_(self, exp):
        try:
            val = eval(exp)
            return val
        except:
            return str(exp)

    def CPrint(self, text = None, JustTextBG : bool = False):
        width = os.get_terminal_size().columns 
        text = self.eval_(text)

        if text != None:
            if type(text).__name__ == "list" or type(text).__name__ == "set" or type(text).__name__ == "tuple" or type(text).__name__ == "dict":
                text = Decor.prettyprint(text)
            else:
                text = str(text)

            lines = text.splitlines()
            
            length_lines = [(len(line), line) for line in lines]

            
            for i, line in enumerate(length_lines):
                if not JustTextBG:
                    print(line[1] + " " * (width - line[0]), end="")
                else:
                    print(line[1] , end="")
                    print(self.DefaultColorEscape, end="")
                    if i == len(length_lines) - 1:
                        print(" " * (width - line[0]), end= "")
                        print(self.DefaultColorEscape, end="")

                    else:
    
                        print(" " * (width - line[0]))
                        print(self.ColorEscape, end="")

    def Colorize(self, JustTextBG : bool = False):
        print(self.ColorEscape, end="")

        text = self.string
        self.CPrint(text = str(text), JustTextBG = JustTextBG)

        print(self.DefaultColorEscape, end="\n")

    def Input(self, prompt: str = ""):
        print(self.ColorEscape, end="")
        prompt = prompt.splitlines()
        width = os.get_terminal_size().columns 
        for i, txt in enumerate(prompt):
            if i != len(prompt) - 1:
                print(txt, " " * ((width-1) - len(txt)))
            else:
                value = input(txt)
        print(self.DefaultColorEscape, end="")
        return value

    def Reset(self):
        print(self.ResetEscape)

    def SetDefaultTheme(self):
        print(self.DefaultColorEscape + "")



# -----------------------------------Tests---------------------------------------------------- #


# colorize = ANSI_Colorizer


# colorize.DefaultBg = "BRIGHT_CYAN"
# colorize.DefaultFg = "BLACK"

# colorize().SetDefaultTheme()

# colorize(FgColor="BLACK", BgColor="BRIGHT_CYAN", string="Hope this works...").Colorize()

# colorize().Reset()



from .ColorSet import ColorSet
from .Decor import Decor

import curses
from curses import wrapper
import time
import os


class MenuDriver:

    SELECTION_STYLE = {
        "INVERT": curses.A_REVERSE,
        "LIGHT_HIGHLIGHT": curses.A_BLINK,
        "BOLD" : curses.A_BOLD,
        "STANDOUT": curses.A_STANDOUT
    }

    def __init__(self, TextColorizer, MenuList, FgColor : str = None, BgColor : str = None, header: str = " ", header_border_style = "simple", separatorStyle = "simple_dash", SelectionStyle: str = 0) -> None:
        
        self.MenuList = MenuList
        self.choice = 0
        self.width = os.get_terminal_size().columns
        self.SelectionStyle = ["INVERT"] if SelectionStyle == 0 else SelectionStyle.split()

        self.header = "---Menu header here---" if header == " " else header
        self.header_border_style = header_border_style
        self.separatorStyle = separatorStyle

        self.colors = ColorSet.MENU_COLOR_SET#

        self.default_fg = self.colors[TextColorizer.DefaultFg]#
        self.default_bg = self.colors[TextColorizer.DefaultBg]#

        self.FgColor = self.colors[TextColorizer.DefaultFg] if FgColor == None else self.colors[FgColor]#
        self.BgColor = self.colors[TextColorizer.DefaultBg] if FgColor == None else self.colors[BgColor]#

        wrapper(self.Menu)


    

    def Menu(self, stdscr):
       
        self.stdscr = stdscr

        def Cprint(string: str = " ", color_pair: int = 1):
            lines = string.splitlines()
            for line in lines:
                self.stdscr.addstr(f"{line}{' ' * (self.width - len(line))}", curses.color_pair(color_pair))

        self.maxWidth = max([len(i) for i in self.MenuList])
        curses.init_pair(1, self.FgColor, self.BgColor)


        
        self.stdscr.clear()
        
        

        while True:
            
            self.stdscr.clear()

            Cprint(f"{Decor.boxstr(style = self.header_border_style, string = self.header)}\n\n", 1)

            Cprint(f"+{Decor.drawLine(style = self.separatorStyle, length = self.maxWidth + 2)}+\n", 1)

            style = 0
            for i in self.SelectionStyle:
                style = style|self.SELECTION_STYLE[i]
            for i, option in enumerate(self.MenuList):
                if i == self.choice:
                    
                    selected_option = f">> {option}"
                    self.stdscr.addstr(f"{selected_option}{' ' * (self.width - len(selected_option))}", curses.color_pair(1) | style)
                    self.stdscr.refresh()
                else:
                    Cprint(option, 1)
                    self.stdscr.refresh()

            Cprint(f"+{Decor.drawLine(style = self.separatorStyle, length = self.maxWidth + 2)}+\n", 1)
            Cprint(string = "\n# Use arrow keys to navigate\n# Press Enter to select\n# Press Esc to cancell\n\n", color_pair = 1)
            try:
                self.key = self.stdscr.getkey()
            except:
                self.key = None
            
            
            if self.key == "KEY_RIGHT" or self.key == "KEY_DOWN":
                if self.choice >= len(self.MenuList) - 1:
                    self.choice = 0
                else:
                    self.choice += 1
            elif self.key == "KEY_LEFT" or self.key == "KEY_UP":
                if self.choice <= 0:
                    self.choice = len(self.MenuList) - 1
                else:
                    self.choice -= 1
            elif self.key == "\n":
                self.stdscr.addstr(f"Redirecting to {self.MenuList[self.choice]}", curses.color_pair(1) | style)
                self.stdscr.refresh()

                time.sleep(1.5)
                break
            elif self.key == "\x1b":

                self.stdscr.addstr("Cancelled. Press any key to continue.")
                self.stdscr.refresh()

                self.stdscr.getch()
                return None
                break

    def GetChoice(self):
        return self.MenuList[self.choice]
           



# choice = MenuDriver(MenuList = ["Option1", "Option2", "Option3", "Option4"]).GetChoice()

# print(choice)


from .Decor import Decor
from .ANSI_Colorizer import ANSI_Colorizer
from .Win7_Colorizer import Win7_Colorizer
from .MenuDriver import MenuDriver

import sys
import platform

menuDriver = MenuDriver
decor = Decor
TextColorizer = Win7_Colorizer if "Windows" in platform.platform() and int(platform.release()) < 10 else ANSI_Colorizer


class CliUtils:
    def __init__(self):
        
        self.shellArgs = sys.argv[1::]

        self.commands = {}

    def __call__(self, func):
        self.command(func)
        self._execute()
        

    def command(self, func):
        self.commands[func.__name__] = func

    def getargs(self):
        command = self.shellArgs[0]
        options = [opts for opts in self.shellArgs if opts.startswith("-")]
        args = self.shellArgs[-1] if self.shellArgs[-1] not in command and self.shellArgs[-1] not in options else None

        return command, options, args
    def getCommands(self):
        return self.commands
    
    def _execute(self):
        command, options, args = self.getargs() 

        if command in list(self.commands.keys()):
            try:
                self.commands[command](options, args)
            except:
                self.commands[command](args)
    


# ------------------------------------Extra function------------------------------------------

def colorizeText(string = "", FgColor : str = None, BgColor : str = None, JustTextBG: bool = False):

    only_text = JustTextBG

    TextColorizer(string = string, FgColor = FgColor, BgColor = BgColor).Colorize(JustTextBG = only_text)


def Input(prompt = "", FgColor : str = None, BgColor : str = None):
    value = TextColorizer(FgColor = FgColor, BgColor = BgColor).Input(prompt=prompt)
    return value


def Print(*text, sep: str = " ", end: str = "\n"):
    TextColorizer.Print(*text, sep = sep, end = end)


def init_boxStyle(StyleName: str, BoxChars: tuple):
    if StyleName != None and BoxChars != None:
        Decor.init_box_style(StyleName, BoxChars)
    else:
        pass


def init_lineStyle(StyleName: str, LineChar: tuple):
    if StyleName != None and LineChar != None:
        Decor.init_line_style(StyleName, LineChar)
    else:
        pass    



# ---------------------------------------------Tests-----------------------------------------------------



# @CliUtils()
# def greet(name):
#     print("hello", name)



from setuptools import setup, find_packages

setup(name = "prettyfy",
      version = 0.2,
      description= "A package of the students to beautify their console",
      author= "T S Shannmukh Vshtav",
      long_description_content_type = "text/markdown",
      long_description= open("README.md").read(),
      packages=["prettyfy"],
      url = "https://github.com/Shanmukh-dev/Prettyfy-Package",
      install_requires = ["windows-curses; sys_platform == 'win32'",],
      entry_points = {
          'console_scripts': [
              "prettyfy = prettyfy.safe_exec:safe_exec"
          ],
      },
      )


import ctypes as ct
from .ColorSet import ColorSet
from .Decor import Decor

import os


class Win7_Colorizer():
    # ct.windll.kernel32.SetConsoleTextAttribute(stdout,0x0080 | 0x0008 |0x0070 | 0x0004)
    # bgIntensity|fgIntensity|BgColor|FgColor
    DefaultFg: str = "white"
    DefaultBg: str = "black"
    intensify: bool = False
    def Print(*text, sep: str = " ", end: str = "\n"):
        width = os.get_terminal_size().columns - 1
        text = (" ",) if text == () else text
        print_contents = " "

        if len(text) == 1:
            if type(text[0]).__name__ == "list" or type(text[0]).__name__ == "set" or type(text[0]).__name__ == "tuple" or type(text[0]).__name__ == "dict":
                print_contents = Decor.prettyprint(text[0])
            else:
                string_list = map(str, text)
                print_contents = sep.join(string_list)
        else:        
            string_list = map(str, text)
            print_contents = sep.join(string_list)

        lines = print_contents.splitlines()
        length = [(len(line), line) for line in lines]
        for line in length:
            
            print(line[1] + " " * (width - line[0]), sep = sep, end = end)

    def __init__(self, string="", FgColor: str = None, BgColor: str = None) -> None:

        FgColor = self.DefaultFg if FgColor == None else FgColor
        BgColor = self.DefaultBg if BgColor == None else BgColor

        self.STDHANDLE = -11

        self.COLORS = ColorSet.WIN7_COLOR_SET
        self.stdout = ct.windll.kernel32.GetStdHandle(self.STDHANDLE)
        self.colorInitiator = ct.windll.kernel32.SetConsoleTextAttribute

        self.default_fg = self.COLORS["FOREGROUND"][self.DefaultFg]
        self.default_bg = self.COLORS["BACKGROUND"][self.DefaultBg]

        self.BgColor = BgColor
        self.FgColor = FgColor
        self.string = string

        
    def eval_(self, exp):
        try:
            val = eval(exp)
            return val
        except:
            return str(exp)

    def CPrint(self, text : str = None, JustTextBG : bool= False):
        width = os.get_terminal_size().columns - 1
        text = self.eval_(text)

        if text != None:
            if type(text).__name__ == "list" or type(text).__name__ == "set" or type(text).__name__ == "tuple" or type(text).__name__ == "dict":
                text = Decor.prettyprint(text)
            else:
                text = str(text)

            lines = text.splitlines()
            
            length_lines = [(len(line), line) for line in lines]
            for i, line in enumerate(length_lines):
                if not JustTextBG:
                    print(line[1] + " " * (width - line[0]))
                else:

                    print(line[1], end = "", flush = True)
                    self.SetDefaultTheme()
                    print(" " * (width - line[0]))
                    self.colorInitiation()

    def colorInitiation(self):
        self.colorInitiator(
                self.stdout, self.COLORS["BACKGROUND"][self.BgColor] | self.COLORS["FOREGROUND"][self.FgColor])

            

    def Colorize(self, JustTextBG : bool = False):
        
        self.colorInitiation()
        onlyText = JustTextBG
        
        self.CPrint(self.string, JustTextBG = onlyText)
        self.SetDefaultTheme()


    def Input(self, prompt: str = ""):
        self.colorInitiation()
        prompt = prompt.splitlines()
        width = os.get_terminal_size().columns 
        for i, txt in enumerate(prompt):
            if i != len(prompt) - 1:
                print(txt, " " * ((width-1) - len(txt)))
            else:
                value = input(txt)
        self.SetDefaultTheme()
        return value


    def SetDefaultTheme(self):
        self.colorInitiator(self.stdout, self.default_bg | self.default_fg)

    def Reset(self):
        self.colorInitiator(
            self.stdout, self.COLORS["BACKGROUND"]["black"] | self.COLORS["FOREGROUND"]["white"])


# -----------------------------------Tests---------------------------------------------------- #


# Win7_Colorizer(string="Hope this works", DefaultBg="RED",
#             DefaultFg="BLUE").Colorize()
# print("")
# Win7_Colorizer(FgColor="BLACK", BgColor="CYAN", string="Hope this works",
#             DefaultBg="RED", DefaultFg="BLUE").Colorize()
# print("")

# Win7_Colorizer(string="Hope this works", DefaultBg="RED",
#             DefaultFg="BLUE").Colorize()

# Win7_Colorizer().Reset()


# colorize = Win7_Colorizer

# colorize.DefaultBg = "CYAN"
# colorize.DefaultFg = "BLACK"

# colorize().SetDefaultTheme()
# colorize(FgColor="BLACK", BgColor="CYAN", string="Hope this works...").Colorize()

# colorize.intensify = True

# colorize(FgColor="WHITE", BgColor="RED", string="This must be bright").Colorize()

# colorize.intensify = False

# colorize(FgColor="WHITE", BgColor="RED", string="This must be normal").Colorize()


# colorize().Reset()
